@@ -52,7 +52,7 @@ package com.openexchange.subscribe.crawler.internal;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.InputStream;
-import org.yaml.snakeyaml.Yaml;
+import org.ho.yaml.Yaml;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Streams;
 import com.openexchange.subscribe.SubscriptionErrorMessage;
@@ -66,13 +66,11 @@ import com.openexchange.subscribe.crawler.Workflow;
 public class WorkflowFactory {
 
     public static Workflow createWorkflow(final String filename) throws OXException {
+
         InputStream input = null;
         try {
             input = new FileInputStream(filename);
-            Yaml yaml = new Yaml();
-            Workflow workflow = yaml.loadAs(input, Workflow.class);
-            //checkSanity(workflow);
-            return workflow;
+            return Yaml.loadType(input, Workflow.class);
         } catch (final FileNotFoundException e) {
             throw new IllegalArgumentException(e.getMessage(), e);
         } finally {
@@ -80,11 +78,8 @@ public class WorkflowFactory {
         }
     }
 
-    public static Workflow createWorkflowByString(final String string) throws OXException {
-        Yaml yaml = new Yaml();
-        Workflow workflow = yaml.loadAs(string, Workflow.class);
-        //checkSanity(workflow);
-        return workflow;
+    public static Workflow createWorkflowByString(final String yamlText) throws OXException {
+        return Yaml.loadType(yamlText, Workflow.class);
     }
 
     private static void checkSanity(final Workflow workflow) throws OXException {
